pub struct ValgrindStackRegistration { /* private fields */ }
Helper type which registers a stack with Valgrind and automatically de-registers it when dropped.

This has no effect when not running under Valgrind.

Implementations

source

impl ValgrindStackRegistration

source

pub fn new(addr: *mut u8, len: usize) -> Self

Registers the given region of memory as a stack so that Valgrind can properly recognize legitimate stack switches.