TrapHandlerRegs

Struct TrapHandlerRegs 

pub struct TrapHandlerRegs {
    pub rip: u64,
    pub rsp: u64,
    pub rbp: u64,
    pub rdi: u64,
    pub rsi: u64,
}
Registers which must be updated upon return from a trap handler.

The exact set of registers that need to be updated varies depending on the target. Note that all registers must be updated to the specified values, otherwise behavior is undefined.

To catch any issues at compilation time, it is recommended to use Rust’s pattern matching syntax to extract the individual registers from this struct.

let TrapHandlerRegs { rip, rsp, rbp, rdi, rsi } = regs;

Fields

rip: u64rsp: u64rbp: u64rdi: u64rsi: u64