Struct corosensei::stack::valgrind::ValgrindStackRegistration
source · pub struct ValgrindStackRegistration { /* private fields */ }Expand description
Helper type which registers a stack with Valgrind and automatically de-registers it when dropped.
This has no effect when not running under Valgrind.
Implementations